%% Instruction
% 1. Replace subject number for running this code for other subjects. For
% example, find and replace "subn" with "subn+1". 
% 2. "Electrode info" for all patients can be found in "info_channel.m".
% Replace this section with contents in "info_channel.m" for other
% patients. 

%% Initialize functions
addpath_recurse('chronux_2_12');
addpath_recurse('functions_general');

%%
load(fullfile('data_recording','sub3','nf_sub3.mat')); % substitue for other subjects
raw_voltage = nf_sub3; 

%% Electrode info (see instruction for other patients) 
bad_channel = [6 8:12 18:21 23:33 37 38 41 44 46:48 51:57 61 62 69:74 76:79 83 85:92 94 97 98 101:107 110 114:116 121 125 126 ...
    128 130 132:135 140:144 146:150 156 157 161 162 167 170 172:177 182:184 189 191 193 194];
total_channel = 194;
good_channel = sort(setdiff(1:total_channel,bad_channel)); 
sr = 2048;

%%
load(fullfile('data_recording','sub3','trigger_info.mat'));
load(fullfile('data_recording','sub3','result_gamma','sub3_art_flanker.mat'));
load(fullfile('data_recording','sub3','result_gamma','A02_gamma_flanker_sub3.mat'));
load(fullfile('data_psychophysics','sub3','congruency_flanker'));
load(fullfile('data_psychophysics','sub3','rt_flanker'));
load(fullfile('data_psychophysics','sub3','correct_flanker'));
load('t_trial.mat'); 

%% Analyze response aligned 
before_voice = sr*2.5;
after_voice = sr*2.5;
filter_space = sr; 
filter_space_after = sr*2;
normRange = sr/2; 

for i_channel = 139%good_channel
    art = sub3_art_flanker{i_channel}; 
    %raw_voltage(i_channel,:) = ft_preproc_lowpassfilter(raw_voltage(i_channel,:),sr,300, 4, 'but');
    current = 1;
    correct_ind = 1; 
    for i = 1:height(trigger_info)
        if strcmp(trigger_info.task{i},'flanker') && strcmp(trigger_info.message{i},'stim_on')
            
            if  correct_flanker(correct_ind)==1 && ~ismember(correct_ind,art) 
                rt =round(rt_flanker(correct_ind)/1000*sr);
                rt_sec(current) = rt_flanker(correct_ind)/1000; 
                start = trigger_info.timestamp(i-1)-filter_space; 
                ending = trigger_info.timestamp(i+1)+filter_space_after; 
                trials_response{current} = raw_voltage(i_channel,start:ending); 
                
                
                
                base_start = trigger_info.timestamp(i-1)-filter_space; 
                base_end = trigger_info.timestamp(i-1)+normRange+filter_space; 
                base{current} = raw_voltage(i_channel,base_start:base_end); 
                
                trial_start  = trigger_info.timestamp(i)-filter_space;
                trial_end = trigger_info.timestamp(i+1)+filter_space;
                
                congruency(current) = congruency_flanker(correct_ind); 
                                
                
                current = current+1; 
                correct_ind = correct_ind+1; 
            else
                correct_ind = correct_ind+1; 
            end
        end
    end
    
    t_now = t_trial(93:end);
    t_now = t_now-(t_now(1)-(-0.5)); % make the t_now(1) = -0.5, 

    for i = 1:length(trials_response) 
        this_trial =  trials_response{i};
        params.fpass = [70 120];params.err = [1 0.01];
        params.movingwin = [0.2 0.01];
        params.tapers = [5 7];
        this_trial = computeNormalizedFreqMag(this_trial',sr,params);
        mean_rt = nanmean(rt_flanker)/1000; 
        
        this_trial = this_trial(93:end); 
        this_base = computeNormalizedFreqMag(base{i}',sr,params);
        this_base = this_base(93:144); 
        mean_base = mean(this_base); 
        this_trial = this_trial-mean_base; 
        this_trial = this_trial./std(this_base);
        [~,start_ind] = min(abs(t_now-(0)));
        [~,final_ind] = min(abs(t_now-(rt_sec(i))));
        curr_trial = this_trial(start_ind:final_ind);
        trial_mean(i) = mean(curr_trial); 
        
    end
      
    con_ind = find(congruency==1); 
    incon_ind = find(congruency==-1);  
    con_rt = rt_sec(con_ind); 
    incon_rt = rt_sec(incon_ind); 
    mean_con = trial_mean(con_ind);
    mean_in = trial_mean(incon_ind); 
    fit_con=fitlm(con_rt,trial_mean(con_ind)); p_con = fit_con.Coefficients.pValue(2);
    fit_in = fitlm(incon_rt,trial_mean(incon_ind)); p_in = fit_in.Coefficients.pValue(2);
    if p_con<=0.05
        rtCorr_flanker_sub3(i_channel,5) = 1;
    else
        rtCorr_flanker_sub3(i_channel,5) = 0;
    end
    if p_in<=0.05
        rtCorr_flanker_sub3(i_channel,6) = 1;
    else
        rtCorr_flanker_sub3(i_channel,6) = 0;
    end
    

    %% Plot mean con (7B left)
        figure(1)
        scatter(con_rt,mean_con,4,'filled','k')
        P = polyfit(con_rt,mean_con,1);
        yfit = P(1)*con_rt+P(2);
        hold on;
        plot(con_rt,yfit,'k-');
        xlabel('Reaction time (s)');
        ylabel('Mean \gamma power');  
        %legend_text = sprintf('Stroop (c), n=%d',length(con_rt));
        %legend(legend_text,sprintf('p=%.3f',p_con));
        names = string([-0.4:0.4:2]);
        set(gca,'fontsize', 8,'xtick',[-0.4:0.4:2],'xticklabel',names,'TickDir','out','FontName','Arial','box','off')

        
        %% Plot mean in (7B right)
        figure(2)
        scatter(incon_rt,mean_in,4,'filled','k')
        P = polyfit(incon_rt,mean_in,1);
        yfit = P(1)*incon_rt+P(2);
        hold on;
        plot(incon_rt,yfit,'k-');
        xlabel('Reaction time (s)');
        %ylabel('Mean \gamma power (z-scored)');  
        %legend_text = sprintf('Stroop (i), n=%d',length(incon_rt));
        %legend(legend_text,sprintf('p=%.3f',p_in));
        names = string([-0.4:0.4:2]);
        set(gca,'fontsize', 8,'xtick',[-0.4:0.4:2],'xticklabel',names,'TickDir','out','FontName','Arial','box','off')
    
    %%
     %clear con_matrix congruency incon_matrix trials_matrix trials_response base p sum5 type1_matrix ...
    %     type2_matrix type3_matrix type4_matrix type5_matrix type6_matrix type7_matrix type8_matrix type9_matrix trials_stimAlign 
end
%save('rtCorr_flanker_sub3.mat','rtCorr_flanker_sub3'); 


